/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 */

 /* (C) Marcin Kwadrans <quar@vitea.pl> */

#include "include/support.h"
#include "include/variable.h"
#include "include/symbol.h"

class LWVariableGeneric: public LWVariable, public LWSymbol {

const gchar *getName ()
{
	return "variable";
}	

gchar *getHint ()
{
	return _("Variable");
}

gboolean isValue ()
{
	return TRUE;
}

gboolean canClone ()
{
	return FALSE;	
}

};

LWSymbol *new_LWVariableGeneric()
{
	return new LWVariableGeneric();
}
